# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nannyml',
 'nannyml.datasets',
 'nannyml.datasets.data',
 'nannyml.drift',
 'nannyml.drift.model_inputs',
 'nannyml.drift.model_inputs.multivariate',
 'nannyml.drift.model_inputs.multivariate.data_reconstruction',
 'nannyml.drift.model_inputs.univariate',
 'nannyml.drift.model_inputs.univariate.statistical',
 'nannyml.drift.model_outputs',
 'nannyml.drift.target',
 'nannyml.drift.target.target_distribution',
 'nannyml.performance_calculation',
 'nannyml.performance_estimation',
 'nannyml.performance_estimation.confidence_based',
 'nannyml.plots',
 'tests',
 'tests.performance_calculation',
 'tests.performance_estimation']

package_data = \
{'': ['*'], 'tests': ['manual/*']}

install_requires = \
['category-encoders>=2.3.0,<3.0.0',
 'joblib>=1.1.0,<2.0.0',
 'matplotlib>=3.5.1,<4.0.0',
 'offset>=0.0.2,<0.0.3',
 'pandas>=1.3.0,<2.0.0',
 'plotly>=5.6.0,<6.0.0',
 'python-dateutil>=2.8.2,<3.0.0',
 'scikit-learn>=1.0.2,<2.0.0',
 'scipy>=1.7.3,<1.8.0',
 'seaborn>=0.11.2,<0.12.0',
 'types-python-dateutil>=2.8.9,<3.0.0']

extras_require = \
{'dev': ['tox>=3.20.1,<4.0.0',
         'virtualenv>=20.2.2,<21.0.0',
         'pip>=20.3.1,<21.0.0',
         'twine>=3.3.0,<4.0.0',
         'pre-commit>=2.12.0,<3.0.0',
         'toml>=0.10.2,<0.11.0',
         'bump2version>=1.0.1,<2.0.0'],
 'doc': ['Sphinx>=4.4.0,<5.0.0',
         'sphinx-rtd-theme>=1.0.0,<2.0.0',
         'jupyterlab>=3.2.9,<4.0.0'],
 'test': ['black>=22.3.0,<23.0.0',
          'isort>=5.8.0,<6.0.0',
          'flake8>=3.9.2,<4.0.0',
          'flake8-docstrings>=1.6.0,<2.0.0',
          'mypy>=0.900,<0.901',
          'pytest>=6.2.4,<7.0.0',
          'pytest-cov>=2.12.0,<3.0.0',
          'pytest-mock>=3.7.0,<4.0.0']}

setup_kwargs = {
    'name': 'nannyml',
    'version': '0.3.0',
    'description': 'The NannyML library, monitoring model performance since 2020.',
    'long_description': '=======\nNannyML\n=======\n\n.. image:: https://img.shields.io/pypi/v/nannyml.svg\n    :target: https://pypi.org/project/nannyml/\n    :alt: PyPi\n\n.. image:: https://img.shields.io/pypi/pyversions/nannyml.svg\n    :target: https://pypi.org/project/nannyml/\n    :alt: Supported versions\n\n.. image:: https://github.com/NannyML/nannyml/actions/workflows/dev.yml/badge.svg\n    :target: https://github.com/nannyml/nannyml/actions/workflows/dev.yml\n    :alt: Build status\n\n.. image:: https://codecov.io/gh/NannyML/nannyml/branch/main/graph/badge.svg?token=OGpF5gVzfR\n    :target: https://codecov.io/gh/NannyML/nannyml\n    :alt: coverage\n\n\nThe NannyML library\n\n* GitHub repo: https://github.com/nannyml/nannyml\n* Documentation: https://nannyml.readthedocs.io/\n* Free software: Apache 2.0 license\n\nFeatures\n--------\n\n* Automated metadata extraction\n* Drift calculation\n* Model performance metrics\n* Model performance estimation\n',
    'author': 'Niels Nuyttens',
    'author_email': 'niels@nannyml.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/nnansters/nannyml',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7.1,<3.11',
}


setup(**setup_kwargs)
